==> apache-qpid-broker-j-7.1.12-src.tar.gz: apache-qpid-broker-j-7.1.12-src/systests/protocol-tests-core/src/main/java/org/apache/qpid/tests/protocol/Matchers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.qpid.tests.protocol;

import java.util.Arrays;

import org.hamcrest.BaseMatcher;
import org.hamcrest.Description;
import org.hamcrest.Matcher;

public class Matchers
{
    public static Matcher<Response> protocolHeader(byte[] expectedHeader)
    {
        return new BaseMatcher<Response>()
        {
            @Override
            public void describeTo(final Description description)
            {
                description.appendValue(new HeaderResponse(expectedHeader));
            }

            @Override
            public boolean matches(final Object o)
            {
                if (o == null)
                {
                    return false;
                }
                if (!(o instanceof HeaderResponse))
                {
                    return false;
                }
                if (!Arrays.equals(expectedHeader, ((HeaderResponse) o).getBody()))
                {
                    return false;
                }
                return true;
            }
        };
    }
}

==> apache-qpid-broker-j-10.0.1-src.tar.gz: apache-qpid-broker-j-10.0.1-src/systests/protocol-tests-core/src/main/java/org/apache/qpid/tests/protocol/Matchers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.qpid.tests.protocol;

import java.util.Arrays;

import org.hamcrest.BaseMatcher;
import org.hamcrest.Description;
import org.hamcrest.Matcher;

public class Matchers
{
    public static Matcher<Response> protocolHeader(final byte[] expectedHeader)
    {
        return new BaseMatcher<>()
        {
            @Override
            public void describeTo(final Description description)
            {
                description.appendValue(new HeaderResponse(expectedHeader));
            }

            @Override
            public boolean matches(final Object o)
            {
                if (o == null)
                {
                    return false;
                }
                if (!(o instanceof HeaderResponse))
                {
                    return false;
                }
                if (!Arrays.equals(expectedHeader, ((HeaderResponse) o).getBody()))
                {
                    return false;
                }
                return true;
            }
        };
    }
}
